aboutsummaryrefslogtreecommitdiffstats
path: root/ports/darwin/guts/getxattr.c
diff options
context:
space:
mode:
Diffstat (limited to 'ports/darwin/guts/getxattr.c')
-rw-r--r--ports/darwin/guts/getxattr.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ports/darwin/guts/getxattr.c b/ports/darwin/guts/getxattr.c
index 96fc1e8..16f0993 100644
--- a/ports/darwin/guts/getxattr.c
+++ b/ports/darwin/guts/getxattr.c
@@ -2,11 +2,11 @@
* Copyright (c) 2011 Wind River Systems; see
* guts/COPYRIGHT for information.
*
* ssize_t getxattr(const char *pathname, const char *name, void *value, size_t size)
* ssize_t rc = -1;
*/
- rc = real_getxattr(pathname, name, value, size);
+ rc = real_getxattr(pathname, name, value, size, position, options);
/* return rc;
* }
@@ -2,11 +2,11 @@
* guts/COPYRIGHT for information.
*
- * ssize_t getxattr(const char *pathname, const char *name, void *value, size_t size)
+ * ssize_t getxattr(const char *pathname, const char *name, void *value, size_t size, u_int32_t position, int options)
* ssize_t rc = -1;
*/